# Repository path:    $HeadURL: https://90.145.156.222/DMS-Houtribdijk/code/python-ftp-svn/source/fewsServices/ReadFewsPy.py $
# Last committed:     $Revision: 173444 $; $Author: svcdms $; $Date: 2019-06-21 11:53:53 +0200 (vr, 21 jun 2019) $
#
import hkvfewspy
from zeep import exceptions as zeep_exceptions
from requests import exceptions
import io


class ReadFewsPy:
    def __init__(self, logger, url, filter_id):
        self._pi = hkvfewspy.Pi()

        try:
            self._pi.setClient(wsdl=url)
        except exceptions.ConnectionError as e:
            logger.error("ReasFewsPy.init: {}".format(str(e)))
            exit(1)
        except KeyError as e:
            logger.error("ReadFewsPy.init: Filter {} not found".format(filter_id))
            exit(1)

    def read_timeseries(
        self, logger, filter_id, par_ids, loc_ids, start_date, end_date, client_timezone
    ):
        # create pi-timeseries object
        pi_query = self._pi.setQueryParameters()

        pi_query.clientTimeZone(client_timezone)
        pi_query.filterId(filter_id)
        pi_query.parameterIds(par_ids)
        pi_query.locationIds(loc_ids)
        pi_query.startTime(start_date)
        pi_query.endTime(end_date)

        # request timeseries
        try:
            df_timeseries = self._pi.getTimeSeries(
                queryParameters=pi_query, header="longform", setFormat="df"
            )
        except ValueError:
            logger.error(
                "ReadFewsPy.read_timeseries: problem reading {},{},{}".format(
                    par_ids, loc_ids, filter_id
                )
            )
            exit(1)
        else:
            return df_timeseries

    def read_parameters(self, logger, filter_id):
        try:
            df_parameters = self._pi.getParameters(filterId=filter_id)
        except zeep_exceptions.Fault as e:
            logger.error("ReadFewsPy.read_parameters: {}".format(str(e)))
            exit(1)
        else:
            return df_parameters

    def read_locations(self, logger, filter_id):
        try:
            df_locations = self._pi.getLocations(filterId=filter_id)
        except zeep_exceptions.Fault as e:
            logger.error("ReadFewsPy.read_locations: {}".format(str(e)))
        else:
            return df_locations
